from random import choice


def internet_check():
    # TODO
    pass


def daily_word():
    # TODO
    pass


def local_word(word=""):
    words = ["PYTHON", "GAME", "DEVELOP", "STEAM", "FLY"]
    if word:
        return word
    else:
        return choice(words)


def random_word():
    # TODO
    pass



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['hangthepyman']

package_data = \
{'': ['*']}

install_requires = \
['pygame>=1.9.6,<2.0.0']

setup_kwargs = {
    'name': 'hangthepyman',
    'version': '0.0.1',
    'description': '\x16Classic Hangman game with Pygame & Python touch',
    'long_description': "# HangThePyMan\n\n> Classic Hangman game with Pygame & Python touch.\n\nImplementation of the hangman game in Pygame. With the ability to ask today's word, most used & searched words and bunch of other fun options to play.\n\n![screen1](screenshots/screen1.png)\n\n## Installation\n\nPip:\n\n```sh\npip install hangthepyman --user\n```\n\nSource:\n\nAfter cloning head to hangthepyman directory and run:\n\n```sh\npython3 the_hangman.py\n```\n\n## TODO's\n\n- Add Menu\n- Add Music\n- Complete word functions to improve asked words and add hint option\n\n## Release History\n\n- 0.0.1\n  - Created the game :)\n\n## Meta\n\nBerkay Girgin – [@Gerile3](https://github.com/Gerile3) – berkay.grgn@protonmail.com\n\nDistributed under the MIT license. See ``LICENSE`` for more information.\n\n## Contributing\n\n1. Fork it (<https://github.com/Gerile3/HangThePyMan/fork>)\n2. Create your feature branch (`git checkout -b feature/fooBar`)\n3. Commit your changes (`git commit -am 'Add some fooBar'`)\n4. Push to the branch (`git push origin feature/fooBar`)\n5. Create a new Pull Request\n",
    'author': 'Berkay Girgin',
    'author_email': 'berkay.grgn@protonmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/Gerile3/HangThePyMan',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)



import os
from string import ascii_uppercase
from words import local_word
import sys
import pathlib


import pygame
import pygame.freetype


class Game:
    WIDTH = 800
    HEIGHT = 500
    RADIUS = 20
    GAP = 15
    GUESSED = ""
    HANGMAN_STATUS = 0
    WON = [False]
    DIR = str(pathlib.Path(__file__).parent.parent.absolute())

    def __init__(self):
        pygame.init()
        self.game_font = pygame.freetype.Font(Game.DIR + '\\fonts\\classic.TTF', 26)
        self.word_font = pygame.freetype.SysFont("comicsans", 50)
        self.win = pygame.display.set_mode((Game.WIDTH, Game.HEIGHT))
        self.caption = pygame.display.set_caption("Hangman The Game")
        self.gameIcon = pygame.image.load(Game.DIR + '\\icon\\icon.png')
        self.icon = pygame.display.set_icon(self.gameIcon)
        self.clock = pygame.time.Clock()
        self.b_color = (255, 255, 255)
        self.run = True
        self.images = self.load_images()
        self.letter_coordinates = self.load_buttons()
        self.word = local_word()

    def load_images(self):
        images = []
        location = Game.DIR + "\\images"
        for i in range(len(os.listdir(location))):
            image = pygame.image.load(location + "\\" + "hangman" + str(i) + ".png")
            images.append(image)
        return images

    def load_buttons(self):
        letter_coordinates = []
        start_x = round((Game.WIDTH - (Game.RADIUS * 2 + Game.GAP) * 13) / 2)
        start_y = 400
        for j in range(len(ascii_uppercase)):
            x = start_x + Game.GAP * 2 + ((Game.RADIUS * 2 + Game.GAP) * (j % 13)) - 15
            y = start_y + ((j // 13)) * (Game.GAP + Game.RADIUS * 2)
            letter_coordinates.append([x, y, ascii_uppercase[j], True])

        return letter_coordinates

    def draw(self):
        display_word = ""
        self.win.fill(self.b_color)

        # draw word
        for letter in self.word:
            if letter in Game.GUESSED:
                display_word += letter + " "
            else:
                display_word += "_ "
        self.word_font.render_to(self.win, (400, 175), display_word, (0, 0, 0))

        # draw letters
        for letter in self.letter_coordinates:
            x, y, char, pressed = letter
            if pressed:
                pygame.draw.rect(self.win, (0, 0, 0), (x, y, 30, 30), 3)
                self.game_font.render_to(self.win, (x + 8, y + 8), char, (0, 0, 0))

        self.win.blit(self.images[Game.HANGMAN_STATUS], (150, 100))
        pygame.display.update()

    def display_message(self, message):
        pygame.time.delay(1000)
        self.win.fill(self.b_color)
        self.word_font.render_to(self.win, (300, 200), message, (0, 0, 0))
        pygame.display.update()
        pygame.time.delay(3000)

    def main(self):
        while self.run:
            self.clock.tick(60)

            for event in pygame.event.get():
                if event.type == pygame.QUIT:
                    self.run = False
                    self.quit()

                if event.type == pygame.MOUSEBUTTONDOWN:
                    m_x, m_y = pygame.mouse.get_pos()
                    # Check collision
                    for ltr in self.letter_coordinates:
                        x, y, char, pressed = ltr
                        if 0 < m_x - x < 30 and 0 < m_y - y < 30 and pressed:
                            distance = (m_x - x) * (m_y - y)
                            if 0 < distance <= 900:
                                ltr[3] = False
                                Game.GUESSED += char
                                if char not in self.word:
                                    Game.HANGMAN_STATUS += 1

                    Game.WON = [True if i in Game.GUESSED and self.word else False for i in self.word]

            self.draw()
            result = self.win_status(Game.WON, Game.HANGMAN_STATUS)

            if result:
                self.run = False
                self.quit()

    def win_status(self, status, hangman_status):
        if hangman_status >= 6:
            self.display_message("You Lost!")
            return True

        if all(status):
            self.display_message("You won!")
            return True
        return False

    def play(self):
        self.main()

    def quit(self):
        pygame.quit()
        sys.exit()
